@@ -86,6 +86,7 @@ DECLARATIVE_CONFIGURATION_CATEGORY = 'Declarative Resource Management'
 MICROSERVICES_CATEGORY = 'Microservices'
 WEB3_CATEGORY = 'Web3'
 SAAS_CATEGORY = 'SaaS'
+VECTOR_SEARCH_CATEGORY = 'Vector Search'
 
 
 # Common markdown.
@@ -514,6 +515,7 @@ class _Common(six.with_metaclass(abc.ABCMeta, object)):
   _release_track = None
   _universe_compatible = None
   _default_universe_compatible = True
+  _regional_endpoint_compatibility = None
   _valid_release_tracks = None
   _notices = None
   _is_deprecated = False
@@ -557,6 +559,10 @@ class _Common(six.with_metaclass(abc.ABCMeta, object)):
   def IsDefaultUniverseCompatible(cls):
     return cls._default_universe_compatible
 
+  @classmethod
+  def RegionalEndpointCompatibility(cls):
+    return cls._regional_endpoint_compatibility
+
   @classmethod
   def IsUnicodeSupported(cls):
     if six.PY2:
@@ -597,6 +603,19 @@ class _Common(six.with_metaclass(abc.ABCMeta, object)):
           return getattr(obj, name)
     return getattr(obj, attribute, None)
 
+  @classmethod
+  def SetRegionalEndpointHelp(cls):
+    entity = (
+        'command group' if getattr(cls, 'IS_COMMAND_GROUP', False)
+        else 'command')
+    support_level = (
+        'requires'
+        if cls._regional_endpoint_compatibility == properties.VALUES.regional.REQUIRED  # pylint:disable=line-too-long
+        else 'supports')
+    help_text = f'This {entity} {support_level} regional endpoints.'
+    cls.detailed_help = getattr(cls, 'detailed_help', {})
+    cls.detailed_help.setdefault('REGIONAL ENDPOINTS', help_text)
+
   @classmethod
   def Notices(cls):
     return cls._notices
@@ -987,6 +1006,9 @@ def _RegionalEndpointCompatibility(compatibility):
     Returns:
       The decorated class.
     """
+    cmd_class._regional_endpoint_compatibility = compatibility  # pylint: disable=protected-access
+    cmd_class.SetRegionalEndpointHelp()
+
     def RunDecorator(run_func):
       @wraps(run_func)
       def WrappedRun(*args, **kw):
@@ -1331,12 +1353,6 @@ def UserProjectQuotaWithFallbackEnabled():
   )
 
 
-def UseRequests():
-  """Returns True if using requests to make HTTP requests.
-  """
-  return True
-
-
 def LogCommand(prog, args):
   """Log (to debug) the command/arguments being run in a standard format.
 
